@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 # .. coding: utf8
-# $Id: test_error_reporting.py 7440 2012-06-13 14:14:12Z milde $
+# $Id: test_error_reporting.py 7464 2012-06-25 13:16:03Z milde $
 # Author: Günter Milde <milde@users.sourceforge.net>
 # Copyright: This module has been placed in the public domain.
 
@@ -36,7 +36,7 @@ except ImportError: # new in Python 2.6
 
 import DocutilsTestSupport              # must be imported before docutils
 from docutils import core, parsers, frontend, utils
-from docutils.error_reporting import SafeString, ErrorString, ErrorOutput
+from docutils.utils.error_reporting import SafeString, ErrorString, ErrorOutput
 from docutils._compat import b, bytes
 
 oldlocale = None
